SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
IF NOT EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[dbo].[UserCreate]') AND type in (N'P', N'PC'))
BEGIN
EXEC dbo.sp_executesql @statement = N'CREATE PROCEDURE [dbo].[UserCreate]
	@EmailAdress  nvarchar(64),
	@PasswordHash nvarchar(128),
	@CultureCode  nvarchar(8)
AS
BEGIN
	SET NOCOUNT ON;

	Declare @ErrorMessage  nvarchar(MAX);
	Declare @ErrorSeverity int;
	Declare @ErrorState    int;

	-- Argument validation...
    Begin Try
	    If (@EmailAdress Is Null)
		    RaisError(N''Argument cannot be null: @EmailAddress'', 16, 1);

		If (@PasswordHash Is Null)
			RaisError(N''Argument cannot be null: @PasswordHash'', 16, 1);

		If (@CultureCode Is Null)
			RaisError(N''Argument cannot be null: @CultureCode'', 16, 1);
	End Try
	Begin Catch
		Set @ErrorMessage  = ERROR_MESSAGE();
		Set @ErrorSeverity = ERROR_SEVERITY();
		Set @ErrorState    = ERROR_STATE();

		RaisError(@ErrorMessage, @ErrorSeverity, @ErrorState);

		return -1;
	End Catch

	-- Implementation, insert a new record into the User table...
	Declare @NewUser table(
		UserGuid     uniqueidentifier,
		EmailAddress nvarchar(64),
		PasswordHash nvarchar(128),
		CultureCode  nvarchar(8),
		LastLoginUtc datetime
	);

	Insert Into [User] (EmailAddress, PasswordHash, CultureCode)
	Output inserted.UserGuid, inserted.EmailAddress, inserted.PasswordHash, inserted.CultureCode, inserted.LastLoginUtc Into @NewUser
	Values (@EmailAdress, @PasswordHash, @CultureCode);

	Select * From @NewUser;

	return 0;
END

' 
END
GO
