﻿namespace Galatea.Data
{
    using System;
    using Galatea.Data.TransportObjects;

    /// <summary>
    /// Defines the interface for a data gateway which interacts with review data in the data store.
    /// </summary>
    public interface IReviewDataGateway : IDisposable
    {
        /// <summary>
        /// Creates a new review in the data store.
        /// </summary>
        /// <param name="value">A data transport object representing the review to create.</param>
        void Create(ref ReviewDTO value);

        /// <summary>
        /// Get a DTO representing a Review
        /// </summary>
        /// <param name="reviewGuid">the unique identifier of the Review</param>
        ReviewDTO Get(Guid reviewGuid);

        /// <summary>
        /// Saves the specified review, and all of its aggregates in the data store.
        /// </summary>
        /// <param name="value">A data transport object representing the review to save.</param>
        void Save(ref ReviewDTO value);
    }
}