﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Galatea.Data.TransportObjects;
using Galatea.DomainModel;

namespace Galatea.Data.Mappers
{
    public class ProjectDataMapper : IDataMapper<Project, ProjectDTO>
    {

        /// <summary>
        /// Creates a new <see cref="T:Galatea.DomainModel.Project"/> object from a data transport
        /// object.
        /// </summary>
        /// <param name="data">A data transport object representing a project.</param>
        /// <returns>A new <see cref="T:Galatea.DomainModel.Project"/> object.</returns>
        /// <exception cref="T:System.ArgumentNullException">
        /// Thrown if the value passed to the <paramref name="data"/> parameter is null.
        /// </exception>
        static internal Project FromDataTransport(ProjectDTO data)
        {
            if (data == null)
                throw new ArgumentNullException("data");

            return new Project
            {
                Name           = data.Name,
                OwnerGuid      = data.OwnerGuid,
                DateCreatedUtc = data.DateCreatedUtc,
                ProjectGuid    = data.ProjectGuid
            };
        }

        /// <summary>
        /// Creates a new <see cref="T:Galatea.Data.TransportObjects.ProjectDTO"/> data transport
        /// object representing this domain model object.
        /// </summary>
        /// <returns>A new <see cref="T:Galatea.Data.TransportObjects.ProjectDTO"/> data transport
        /// object.</returns>
        internal ProjectDTO ToDataTransport(Project model)
        {
            if (model == null)
                throw new ArgumentNullException("model");

            return new ProjectDTO
            {
                Name           = model.Name,
                DateCreatedUtc = model.DateCreatedUtc,
                ProjectGuid    = model.ProjectGuid
            };
        }
    }
}
