﻿namespace Galatea.DomainModel
{
    using System;
    using System.ComponentModel;
    using System.Threading;

    /// <summary>
    /// Defines a domain model object repesenting a user role.
    /// </summary>
    public class UserRole : INotifyPropertyChanged
    {
        /// <summary>
        /// Prevents a default instance of the <see cref="T:Galatea.DomainModel.UserRole"/> class
        /// from being created.
        /// </summary>
        private UserRole()
        {
        }

        /// <summary>
        /// Occurs when a property value changes.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// Raises the <see cref="E:System.ComponentModel.INotifyPropertyChanged.PropertyChanged"/>
        /// event.
        /// </summary>
        /// <param name="e">The <see cref="System.ComponentModel.PropertyChangedEventArgs"/>
        /// instance containing the event data.</param>
        public virtual void OnPropertyChanged(PropertyChangedEventArgs e)
        {
            var handler = Interlocked.CompareExchange(ref this.PropertyChanged, null, null);

            if (handler != null)
                handler(this, e);
        }

        /// <summary>
        /// Gets the name of the user role.
        /// </summary>
        public String Name { get; private set; }

        /// <summary>
        /// Gets a value indicating whether or not users in this role are able to change the name
        /// of a project.
        /// </summary>
        public Boolean CanChangeProjectName { get; private set; }

        /// <summary>
        /// Gets the administrator user role.
        /// </summary>
        static public UserRole Administrator
        {
            get
            {
                return new UserRole
                {
                    Name                 = "Administrator",
                    CanChangeProjectName = true
                };
            }
        }

        /// <summary>
        /// Gets the observer user role.
        /// </summary>
        static public UserRole Observer
        {
            get
            {
                return new UserRole
                {
                    Name                 = "Observer",
                    CanChangeProjectName = false
                };
            }
        }
    }
}