﻿namespace Galatea.Repositories
{
    using System;
    using Galatea.Data;
    using Galatea.DomainModel;
    using Galatea.Data.TransportObjects;

    public class ReviewRepository
    {
        public ReviewRepository(IGalateaDataGatewayFactory dataGatewayFactory, IDataMapper<Review, ReviewDTO> dataMapper)
        {
            this.DataGatewayFactory = dataGatewayFactory;
            this.DataMapper = dataMapper;
        }

        private IGalateaDataGatewayFactory DataGatewayFactory { get; set; }

        private IDataMapper<Review, ReviewDTO> DataMapper { get; set; }

        public void Create(ref Review value)
        {
            if (value == null)
                throw new ArgumentNullException("value");

            // Get a data gateway implementation from the data gateway factory...
            using (var dataGateway = this.DataGatewayFactory.GetReviewDataGateway())
            {
                // Create a new DTO from the domain model object...
                ReviewDTO dto = this.DataMapper.ToDataTransport(value);

                // Pass the DTO into the datagateway for persistance, and receive a new DTO back
                // which represents the persisted entity...
                dataGateway.Create(ref dto);

                // Project the returned DTO back into a domain model object...
                value = this.DataMapper.FromDataTransport(dto);
            }
        }
    }
}