﻿namespace Galatea.Repositories
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;
    using Galatea.Data;
    using Galatea.DomainModel;
    using Galatea.Data.TransportObjects;

    public class RevisionRepository
    {
        /// <summary>
        ///  Initializes a new instance of the <see cref="RevisionRepository"/> class.
        /// </summary>
        /// <param name="dataGatewayFactory"></param>
        /// <param name="dataMapper"></param>
        public RevisionRepository(IGalateaDataGatewayFactory dataGatewayFactory, IDataMapper<Revision, RevisionDTO> dataMapper)
        {
            if (dataGatewayFactory == null)
                throw new ArgumentNullException("dataGatewayFactory");

            if (dataMapper == null)
                throw new ArgumentNullException("dataMapper");

            this.DataGatewayFactory = dataGatewayFactory;
            this.DataMapper         = dataMapper;
        }

        /// <summary>
        /// Gets or sets the data gateway factory.
        /// </summary>
        private IGalateaDataGatewayFactory DataGatewayFactory { get; set; }

        /// <summary>
        /// Gets or sets the data mapper that maps between domain model objects and data transport
        /// objects.
        /// </summary>
        private IDataMapper<Revision, RevisionDTO> DataMapper { get; set; }

        /// <summary>
        /// Creates a new user.
        /// </summary>
        /// <param name="value">A domain model object representing the user to create.</param>
        /// <returns>A new domain model object representing the new user.</returns>
        public void Create(ref Revision value)
        {
            if (value == null)
                throw new ArgumentNullException("value");

            // Get a data gateway implementation from the data gateway factory...
            using (var dataGateway = this.DataGatewayFactory.GetRevisionDataGateway())
            {
                // Create a new DTO from the domain model object...
                var dto = this.DataMapper.ToDataTransport(value);

                // Pass the DTO into the datagateway for persistance, and receive a new DTO back
                // which represents the persisted entity...
                dataGateway.Create(ref dto);

                // Project the returned DTO back into a domain model object...
                value = this.DataMapper.FromDataTransport(dto);
            }
        }

        /// <inheritdoc />
        public Revision GetUser(Guid RevisionGuid)
        {
            using (var dataGateway = this.DataGatewayFactory.GetRevisionDataGateway())
            {
                var dto = dataGateway.Get(RevisionGuid);

                return this.DataMapper.FromDataTransport(dto);
            }
        }
    }
}
