﻿namespace Galatea.Services
{
    using System;
    using System.Diagnostics.Contracts;
    using System.Globalization;
    using AutoMapper;
    using Galatea.DomainModel;
    using Galatea.Repositories;
    using Galatea.Services.TransportObjects;

    public class UserAccountService : IUserAccountService
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="UserAccountService"/> class.
        /// </summary>
        /// <param name="userRepository">The user model repository.</param>
        public UserAccountService(UserRepository userRepository)
        {
            this.UserRepository = userRepository;
        }

        /// <summary>
        /// Gets or sets the user model repository.
        /// </summary>
        private UserRepository UserRepository { get; set; }

        /// <summary>
        /// Registers a new user on the system.
        /// </summary>
        /// <param name="emailAddress">The users email address.</param>
        /// <param name="passwordHash">The users hashed password.</param>
        /// <param name="cultureCode">An EITF culture code representing the users preferred language.</param>
        public void RegisterUser(String emailAddress, String passwordHash, String cultureCode)
        {
            // Argument validation...
            Contract.Requires(String.IsNullOrWhiteSpace(emailAddress) != true);
            Contract.Requires(String.IsNullOrWhiteSpace(passwordHash) != true);
            Contract.Requires(String.IsNullOrWhiteSpace(cultureCode) != true);

            // Try to parse the specified culture code into a culture info object...
            var culture = new CultureInfo(cultureCode);

            // Create the user domain model object...
            var user = new User(emailAddress, passwordHash, culture);

            // Instruct the model repository to save the new user...
            this.UserRepository.Create(ref user);

            // TODO: Perform log in...
        }

        public UserSTO GetUser(Guid userGuid)
        {
            var model = this.UserRepository.GetUser(userGuid);

            return Mapper.Map<UserSTO>(model);
        }
    }
}