﻿namespace Galatea.Data
{
    using System;
    using System.Linq;
    using AutoMapper;
    using Galatea.Data.Entities;
    using Galatea.Data.TransportObjects;

    internal class UserDataGateway : IUserDataGateway
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="UserDataGateway"/> class.
        /// </summary>
        /// <param name="dataContext">The data context.</param>
        public UserDataGateway(GalateaDataContext dataContext)
        {
            if (dataContext == null)
                throw new ArgumentNullException("dataContext");

            this.DataContext = dataContext;
        }

        /// <summary>
        /// Gets or sets the data context.
        /// </summary>
        private GalateaDataContext DataContext { get; set; }

        /// <summary>
        /// Creates a new user in the data store.
        /// </summary>
        /// <param name="value">A data transport object representing the user to create.</param>
        /// <exception cref="T:System.ArgumentNullException">
        /// Thrown if the value passed to the <paramref name="value"/> parameter is null.
        ///   </exception>
        public void Create(ref UserDTO value)
        {
            if (value == null)
                throw new ArgumentNullException("value");

            // Create a new Linq2Sql user entity from the Dto...
            var entity = Mapper.Map<User>(value);

            // Insert the user entity into the table, and submit changes...
            this.DataContext.Users.InsertOnSubmit(entity);
            this.DataContext.SubmitChanges();

            // Convert the user entity back into a dto, including any changes (ie database generated keys)...
            value = Mapper.Map<UserDTO>(entity);
        }

        public UserDTO GetUser(Guid userGuid)
        {
            var userEntity = this.DataContext.Users
                                 .Where(x => x.UserGuid == userGuid)
                                 .Single();

            return Mapper.Map<UserDTO>(userEntity);
        }

        public void Dispose()
        {
            // Intentionally empty..
        }
    }
}