﻿namespace Galatea.Data
{
    using System;

    public sealed class DataGatewayFactory : IGalateaDataGatewayFactory
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="DataGatewayFactory"/> class.
        /// </summary>
        public DataGatewayFactory()
        {
            this.UserDataGateway    = new UserDataGateway();
            this.ProjectDataGateway = new ProjectDataGateway(UserDataGateway.Users);
        }

        /// <summary>
        /// Gets or sets the user data gateway.
        /// </summary>
        private UserDataGateway UserDataGateway { get; set; }

        /// <summary>
        /// Gets or sets the project data gateway.
        /// </summary>
        private ProjectDataGateway ProjectDataGateway { get; set; }

        /// <summary>
        /// Gets an implementation of the user data gateway interface.
        /// </summary>
        /// <returns>
        /// An implementation of the user data gateway interface.
        /// </returns>
        public IUserDataGateway GetUserDataGateway()
        {
            return this.UserDataGateway;
        }

        /// <summary>
        /// Gets an implementation of the project data gateway interface.
        /// </summary>
        /// <returns>
        /// An implementation of the project data gateway interface.
        /// </returns>
        public IProjectDataGateway GetProjectDataGateway()
        {
            return this.ProjectDataGateway;
        }

        /// <summary>
        /// Gets an implementation of the review data gateway interface.
        /// </summary>
        /// <returns>
        /// An implementation of the review data gateway interface.
        /// </returns>
        public IReviewDataGateway GetReviewDataGateway()
        {
            throw new NotImplementedException();
        }
    }
}