﻿namespace Galatea.Data
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using FizzWare.NBuilder;
    using FizzWare.NBuilder.Generators;
    using Galatea.Data.TransportObjects;

    internal sealed class ProjectDataGateway : IProjectDataGateway
    {
        public ProjectDataGateway(IEnumerable<UserDTO> users)
        {
            var random = new Random();

            this.Projects = Builder<ProjectDTO>.CreateListOfSize(20)
                .All()
                    .With(x => x.DateCreatedUtc = GetRandom.DateTimeFrom(DateTime.Now.AddMonths(-1)))
                    .With(x => x.Name = GetRandom.Phrase(35))
                    .With(x => x.OwnerGuid = users.ElementAt(random.Next(users.Count())).UserGuid)
                    .With(x => x.ProjectGuid = GetRandom.Guid())
                .Build();
        }

        internal ICollection<ProjectDTO> Projects { get; private set; }

        public void Create(ref ProjectDTO value)
        {
            value.ProjectGuid = GetRandom.Guid();

            this.Projects.Add(value);
        }

        public void Dispose()
        {
        }
    }
}