﻿namespace Galatea.Data
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using FizzWare.NBuilder;
    using FizzWare.NBuilder.Generators;
    using Galatea.Data.TransportObjects;

    internal sealed class UserDataGateway : IUserDataGateway
    {
        static UserDataGateway()
        {
            Users = Builder<UserDTO>.CreateListOfSize(100)
                .All()
                    .With(x => x.UserGuid = GetRandom.Guid())
                    .And(x => x.PasswordHash = GetRandom.UpperCaseString(128))
                    .And(x => x.LastLoginUtc = GetRandom.DateTimeFrom(DateTime.Now.AddMonths(-1)))
                    .And(x => x.EmailAddress = GetRandom.Email())
                    .And(x => x.CultureCode = "en-GB")
                .Random(30)
                    .With(x => x.CultureCode = "en-US")
                .Random(5)
                    .With(x => x.CultureCode = "de-DE")
                .Random(5)
                    .With(x => x.CultureCode = "jp-JP")
                .Build();
        }

        static internal ICollection<UserDTO> Users { get; private set; }

        public void Create(ref UserDTO value)
        {
            value.UserGuid = GetRandom.Guid();

            Users.Add(value);
        }

        public UserDTO GetUser(Guid userGuid)
        {
            return Users.First(x => x.UserGuid == userGuid);
        }

        public void Dispose()
        {
            // Intentionally empty.
        }
    }
}