﻿namespace Galatea.ServiceLayer
{
    using System;
    using System.Diagnostics.Contracts;
    using System.ServiceModel;
    using System.ServiceModel.Channels;
    using System.ServiceModel.Dispatcher;
    using Ninject;

    internal sealed class NInjectInstanceProvider : IInstanceProvider
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="NInjectInstanceProvider"/> class.
        /// </summary>
        /// <param name="kernel">The kernel.</param>
        /// <param name="serviceType">Type of the service.</param>
        public NInjectInstanceProvider(IKernel kernel, Type serviceType)
        {
            Contract.Requires(kernel != null);
            Contract.Requires(serviceType != null);

            this.Kernel      = kernel;
            this.ServiceType = serviceType;
        }

        /// <summary>
        /// Gets or sets the NInject kernel.
        /// </summary>
        private IKernel Kernel { get; set; }

        /// <summary>
        /// Gets or sets the type of the service.
        /// </summary>
        private Type ServiceType { get; set; }

        /// <summary>
        /// Returns a service object given the specified <see cref="T:System.ServiceModel.InstanceContext"/> object.
        /// </summary>
        /// <param name="instanceContext">The current <see cref="T:System.ServiceModel.InstanceContext"/> object.</param>
        /// <param name="message">The message that triggered the creation of a service object.</param>
        /// <returns>
        /// The service object.
        /// </returns>
        public Object GetInstance(InstanceContext instanceContext, Message message)
        {
            return this.Kernel.Get(this.ServiceType);
        }

        /// <summary>
        /// Returns a service object given the specified <see cref="T:System.ServiceModel.InstanceContext"/> object.
        /// </summary>
        /// <param name="instanceContext">The current <see cref="T:System.ServiceModel.InstanceContext"/> object.</param>
        /// <returns>
        /// A user-defined service object.
        /// </returns>
        public Object GetInstance(InstanceContext instanceContext)
        {
            return this.GetInstance(instanceContext, null);
        }

        /// <summary>
        /// Called when an <see cref="T:System.ServiceModel.InstanceContext"/> object recycles a service object.
        /// </summary>
        /// <param name="instanceContext">The service's instance context.</param>
        /// <param name="instance">The service object to be recycled.</param>
        public void ReleaseInstance(InstanceContext instanceContext, Object instance)
        {
        }
    }
}