﻿namespace Galatea.ServiceLayer
{
    using System;
    using System.ServiceModel;
    using Galatea.Services;
    using Galatea.Services.TransportObjects;

    [ServiceContract]
    [NInjectBehaviour]
    public class UserAccountService : IUserAccountService
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="UserAccountService"/> class.
        /// </summary>
        /// <param name="implementation">The service implementation.</param>
        public UserAccountService(IUserAccountService implementation)
        {
            this.Implementation = implementation;
        }

        /// <summary>
        /// Gets or sets the service implementation.
        /// </summary>
        private IUserAccountService Implementation { get; set; }

        /// <summary>
        /// Registers a new user on the system.
        /// </summary>
        /// <param name="emailAddress">The users email address.</param>
        /// <param name="passwordHash">The users hashed password.</param>
        /// <param name="cultureCode">An EITF culture code representing the users preferred language.</param>
        [OperationContract]
        public void RegisterUser(String emailAddress, String passwordHash, String cultureCode)
        {
            this.Implementation.RegisterUser(emailAddress, passwordHash, cultureCode);
        }

        [OperationContract]
        public UserSTO GetUser(Guid userGuid)
        {
            return this.Implementation.GetUser(userGuid);
        }
    }
}
