﻿namespace Galatea.Web.Controllers
{
    using System;
    using System.Diagnostics.Contracts;
    using System.Web.Mvc;
    using Galatea.Web.Services;
    using Galatea.Web.Models;

    public class UserAccountController : Controller
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="UserAccountController"/> class.
        /// </summary>
        public UserAccountController()
        {
            this.ServiceClient = new UserAccountServiceClient();
        }

        /// <summary>
        /// Gets or sets the user account service client.
        /// </summary>
        private UserAccountServiceClient ServiceClient { get; set; }

        /// <summary>
        /// Handles a GET to the '/UserAccount/Index' url (including '/UserAccount/').
        /// </summary>
        /// <returns></returns>
        [HttpGet]
        public ActionResult Index()
        {
            Contract.Ensures(Contract.Result<ActionResult>() != null);

            this.ViewBag.UserGuid = "9f38a093-41b4-4dc9-a39e-d2c1374598ed";

            return View();
        }

        /// <summary>
        /// Handles a GET to the '/UserAccount/Register' url.
        /// </summary>
        /// <returns>An action result.</returns>
        [HttpGet]
        public ActionResult Register()
        {
            Contract.Ensures(Contract.Result<ActionResult>() != null);

            this.ViewBag.Cultures = new SelectList(new[]
                {
                    new SelectListItem
                    {
                        Text  = "English (Queens)",
                        Value = "en-GB"
                    },
                    new SelectListItem
                    {
                        Text  = "English (American)",
                        Value = "en-US"
                    },
                    new SelectListItem
                    {
                        Text  = "English (Canadian)",
                        Value = "en-CA"
                    },
                }, "Value", "Text", "en-GB");

            return this.View();
        }

        /// <summary>
        /// Handles a POST to the '/UserAccount/Register' url.
        /// </summary>
        /// <param name="viewModel">A view model which encapsulated the form data.</param>
        /// <returns>An action result.</returns>
        [HttpPost]
        [HandleError]
        public ActionResult Register([Bind]RegisterUserViewModel viewModel)
        {
            Contract.Requires(viewModel != null);
            Contract.Ensures(Contract.Result<ActionResult>() != null);

            this.ServiceClient.RegisterUser(viewModel.EmailAddress, viewModel.Password, viewModel.CultureCode);

            return this.RedirectToAction("Index");
        }

        public ActionResult Details(Guid userGuid)
        {
            // Get a service transport object from the service client representing the user with the specified guid...
            var sto = this.ServiceClient.GetUser(userGuid);

            // CReate a new view model from the service transport object...
            var viewModel = new UserDetailsViewModel
            {
                CultureCode  = sto.CultureCode,
                EmailAddress = sto.EmailAddress,
                LastLoginUtc = sto.LastLoginUtc,
                PasswordHash = sto.PasswordHash,
                UserGuid     = sto.UserGuid
            };

            // Pass the view model to the view...
            return this.View(viewModel);
        }
    }
}
